@@ -1,7 +1,7 @@
 """
 Type annotations for dataexchange service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/literals/)
 
 Usage::
 
@@ -38,6 +38,7 @@ __all__ = (
     "ServiceName",
     "ResourceServiceName",
     "PaginatorName",
+    "RegionName",
 )
 
 
@@ -105,6 +106,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -191,6 +193,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -395,3 +398,16 @@ PaginatorName = Literal[
     "list_jobs",
     "list_revision_assets",
 ]
+RegionName = Literal[
+    "ap-northeast-1",
+    "ap-northeast-2",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "eu-central-1",
+    "eu-west-1",
+    "eu-west-2",
+    "us-east-1",
+    "us-east-2",
+    "us-west-1",
+    "us-west-2",
+]
